import { screen, remote } from 'electron'

import { DatabaseFactory } from '../infrastructure/database'
import { APIFactory } from '../application/api'

export default () => {

  const authenticationService = APIFactory.getAuthenticationService()
  const database = DatabaseFactory.getDatabase()

  document.getElementById('submit').addEventListener('click', async () => {
    const usernameEl = document.getElementById('username') as HTMLInputElement
    const username = usernameEl.value
    const passwordEl = document.getElementById('password') as HTMLInputElement
    const password = passwordEl.value
    const autologinEl = document.getElementById('autologin') as HTMLInputElement
    const autologin = autologinEl.value

    // Check for (all) empty fields
    let error = false
    if (username === undefined || username === '') {
      usernameEl.classList.add('error')
      error = true
    } else usernameEl.classList.remove('error')
    if (password === undefined || password === '') {
      passwordEl.classList.add('error')
      error = true
    } else passwordEl.classList.remove('error')
    if (autologin === undefined || autologin === '') {
      autologinEl.classList.add('error')
      error = true
    } else autologinEl.classList.remove('error')

    if (error) return

    try {
      // Retrieve accesskey, start auto turn on/off and forward to monitor
      const accesskey = await authenticationService.getAccesskey(username, password)
      // Persistently save accesskey
      await database.setValueForKey({ accesskey, autologin }, 'tokens')

      // Show fullsize monitor from autologin token
      const BrowserWindow = remote.BrowserWindow
      const currentWindow = remote.getCurrentWindow()
      const { width, height } = screen.getPrimaryDisplay().workAreaSize
      const monitorWindow = new BrowserWindow({
        width,
        height,
        webPreferences: {
          nodeIntegration: false
        }
      })
      monitorWindow.loadURL('https://divera247.com/monitor/1.html?autologin=' + autologin)

      // Create background window which holds display process
      const backgroundTaskWindow = new BrowserWindow({ show: false })
      backgroundTaskWindow.loadFile('src/html/backgroundTask.html')

      // Show console and background window if in app is in debug mode
      const isInDebugMode = process.env.DEBUG === 'true' || process.env.DEBUG === '1'
      if (isInDebugMode) {
        backgroundTaskWindow.webContents.toggleDevTools()
        backgroundTaskWindow.show()
      }

      // Close login window
      currentWindow.close()
    } catch (error) {
      alert(error)
    }
  })

}
